@@ -17,9 +17,9 @@ from headless.ext.picqer import User
 
 async def main():
     params: dict[str, Any]  = {
-        'api_key': os.environ['MOLANO_PICQER_API_KEY'],
+        'api_key': os.environ['PICQER_API_KEY'],
         'api_email': 'test@headless.python.dev.unimatrixone.io',
-        'api_url': 'https://molano.picqer.com/api'
+        'api_url': os.environ['PICQER_API_URL']
     }
     async with Client(**params) as client:
         requests: list[Awaitable[User]] = []
