@@ -28,31 +28,41 @@ class Client(IClient[httpx.Request, httpx.Response]):
     response_class: type[Response] = Response
     request_class: type[Request] = Request
 
-    def __init__(self, *, credential: ICredential | None = None, **kwargs: Any):
+    def __init__(self, *, base_url: str, credential: ICredential | None = None, **kwargs: Any):
         self.credential = credential or self.credential
         self.params = kwargs
-        self._client = httpx.AsyncClient(**kwargs)
+        self._client = httpx.AsyncClient(base_url=base_url, **kwargs)
+        self._in_context = False
+
+    def in_context(self) -> bool:
+        return self._in_context
 
     async def request_factory(
         self,
         method: str,
         url: str,
         json: list[Any] | dict[str, Any] | None = None,
-        headers: dict[str, str] | None = None
+        headers: dict[str, str] | None = None,
+        params: dict[str, Any] | None = None
     ) -> httpx.Request:
         return self._client.build_request(
             method=method,
             url=url,
             json=json,
-            headers=headers
+            headers=headers,
+            params=params
         )
 
     async def send(self, request: IRequest[Any]) -> Response: # type: ignore
         return Response.fromimpl(request, await self._client.send(request.impl))
 
     async def __aenter__(self: T) -> T:
-        await self._client.__aenter__()
+        if not self.in_context():
+            await self._client.__aenter__()
+            self._in_context = True
         return self
 
-    async def __aexit__(self, cls: type[BaseException], *args: Any) -> bool | None:
-        await self._client.__aexit__(cls, *args)
\ No newline at end of file
+    async def __aexit__(self, cls: type[BaseException] | None, *args: Any) -> bool | None:
+        if self.in_context():
+            self._in_context = False
+            await self._client.__aexit__(cls, *args)
\ No newline at end of file
