@@ -6,8 +6,11 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+import re
 from typing import Any
+
 from headless.core import Resource
+from headless.types import IResponse
 
 
 class ShopifyResource(Resource):
@@ -20,6 +23,14 @@ class ShopifyResource(Resource):
             url = url.format(*params)
         return url
 
+    @classmethod
+    def get_next_url(cls, response: IResponse[Any, Any]) -> str | None:
+        m = re.match('^<([^>]+)>; rel="next"', response.headers.get('link') or '')
+        url = None
+        if m is not None:
+            url = m.group(1)
+        return url
+
     @classmethod
     def process_response(
         cls,
